@@ -45,11 +45,13 @@
 #include <cairo.h>
 #include <float.h>
 #include <assert.h>
+#include <errno.h>
 
 #include <linux/input.h>
 #include <wayland-client.h>
 
-#include "src/vertex-clipping.h"
+#include "libweston/vertex-clipping.h"
+#include "shared/xalloc.h"
 #include "window.h"
 
 typedef float GLfloat;
@@ -620,7 +622,8 @@ main(int argc, char *argv[])
 
 	d = display_create(&argc, argv);
 	if (d == NULL) {
-		fprintf(stderr, "failed to create display: %m\n");
+		fprintf(stderr, "failed to create display: %s\n",
+			strerror(errno));
 		return -1;
 	}
 
