@@ -33,7 +33,7 @@
 #include <string.h>
 #include <assert.h>
 
-#include "compositor.h"
+#include <libweston/libweston.h>
 #include "compositor/weston.h"
 #include "fullscreen-shell-unstable-v1-server-protocol.h"
 #include "shared/helpers.h"
@@ -42,6 +42,9 @@ struct fullscreen_shell {
 	struct wl_client *client;
 	struct wl_listener client_destroyed;
 	struct weston_compositor *compositor;
+	/* XXX: missing compositor destroy listener
+	 * https://gitlab.freedesktop.org/wayland/weston/issues/299
+	 */
 
 	struct weston_layer layer;
 	struct wl_list output_list;
@@ -546,7 +549,7 @@ fs_output_configure_for_mode(struct fs_output *fsout,
 					&surf_width, &surf_height);
 
 	/* The actual output mode is in physical units.  We need to
-	 * transform the surface size to physical unit size by flipping ans
+	 * transform the surface size to physical unit size by flipping and
 	 * possibly scaling it.
 	 */
 	switch (fsout->output->transform) {
