@@ -28,11 +28,11 @@
 #include <wayland-server.h>
 #include <assert.h>
 
-#include "compositor.h"
-#include "zalloc.h"
-#include "helpers.h"
+#include <libweston/libweston.h>
+#include <libweston/zalloc.h>
+#include "shared/helpers.h"
 
-#include "libweston-desktop.h"
+#include <libweston-desktop/libweston-desktop.h>
 #include "internal.h"
 
 
