@@ -29,7 +29,7 @@
 #include <stdlib.h>
 #include <linux/input.h>
 
-#include "compositor.h"
+#include <libweston/libweston.h>
 #include "shared/helpers.h"
 #include "shared/timespec-util.h"
 
