@@ -32,7 +32,7 @@
 #include <stdio.h>
 #include <assert.h>
 
-#include "compositor.h"
+#include <libweston/libweston.h>
 #include "shared/helpers.h"
 #include "shared/timespec-util.h"
 
@@ -1152,7 +1152,9 @@ weston_seat_set_selection(struct weston_seat *seat,
 
 	seat->selection_data_source = source;
 	seat->selection_serial = serial;
-	source->set_selection = true;
+
+	if (source)
+		source->set_selection = true;
 
 	if (keyboard)
 		focus = keyboard->focus;
