@@ -33,7 +33,7 @@
 #include <assert.h>
 #include <errno.h>
 
-#include "config-parser.h"
+#include <libweston/config-parser.h>
 #include "string-helpers.h"
 
 static bool
@@ -57,6 +57,7 @@ handle_option(const struct weston_option *option, char *value)
 		return true;
 	default:
 		assert(0);
+		return false;
 	}
 }
 
@@ -75,7 +76,7 @@ long_option(const struct weston_option *options, int count, char *arg)
 
 		if (options[k].type == WESTON_OPTION_BOOLEAN) {
 			if (!arg[len + 2]) {
-				* (int32_t *) options[k].data = 1;
+				* (bool *) options[k].data = true;
 
 				return true;
 			}
@@ -126,7 +127,7 @@ short_option(const struct weston_option *options, int count, char *arg)
 
 		if (options[k].type == WESTON_OPTION_BOOLEAN) {
 			if (!arg[2]) {
-				* (int32_t *) options[k].data = 1;
+				* (bool *) options[k].data = true;
 
 				return true;
 			}
