@@ -31,7 +31,7 @@
 #include "weston-test-runner.h"
 
 #include "shared/helpers.h"
-#include "src/vertex-clipping.h"
+#include "vertex-clipping.h"
 
 #define BOUNDING_BOX_TOP_Y 100.0f
 #define BOUNDING_BOX_LEFT_X 50.0f
